@@ -8,9 +8,13 @@ Documento = []
 
 #_print_Symbol
 
+from IPython.display import Image
+
+
 def Inicializar(n):
   global DatosList,Orden,Estilo
-
+  Image(url='https://i.gyazo.com/0842e5162257727d5b10fd6b4abfdab9.png')
+  
   DatosList = [[sympy.pi,3.14]]
   Orden = 8
   Documento = []
